@@ -10,7 +10,9 @@ from adafruit_ble.services.nordic import UARTService
 
 ble = BLERadio()
 while True:
-    while ble.connected and any(UARTService in connection for connection in ble.connections):
+    while ble.connected and any(
+        UARTService in connection for connection in ble.connections
+    ):
         for connection in ble.connections:
             if UARTService not in connection:
                 continue
